@@ -13,11 +13,11 @@ class MultiMediaMessage(Message):
     def from_dict(cls, message_dict: dict) -> MultiMediaMessage:
         message = Message.from_dict(message_dict)
         return MultiMediaMessage(number=message.number,
-                                 date=message.date,
+                                 datetime_=message.datetime_,
                                  first_contact=message.first_contact,
-                                 type_=message.type_,
+                                 message_type=message.message_type,
                                  read=message.read,
                                  id_=message.id_,
-                                 direction=message.direction,
+                                 message_direction=message.message_direction,
                                  raw=message.raw,
                                  media=message_dict["message"])
